@@ -28,6 +28,8 @@
 mod lex;
 mod parse;
 
+#[cfg(feature = "deb822")]
+pub mod deb822;
 pub mod mangle;
 #[cfg(feature = "pgp")]
 pub mod pgp;
@@ -84,6 +86,7 @@ impl From<SyntaxKind> for rowan::SyntaxKind {
 }
 
 pub use crate::parse::Entry;
+pub use crate::parse::EntryBuilder;
 pub use crate::parse::WatchFile;
 
 #[cfg(test)]
